# use awk, i.e. this is pre-depends of base-files package
global_value_of() {
   awk -v parname="$1" 'BEGIN { regx_to_val="^[ \t]*" parname "[ \t]*=[ \t]*[\042\047]*[ \t]*" }
   {
      if ( /\{[ \t]*$/ )
         exit;

      if ( $0 ~ /^[ \t]*$/ || $0 ~ /^[ \t]*[;#]/ )
         next;

         if ( match($0, regx_to_val) ) {
            val_with_end_quote = substr($0, RLENGTH+1);
            sub( /[\042\047]*[ \t]*;*[ \t]*$/, "", val_with_end_quote);
            print val_with_end_quote;
            exit;
         }
   }' "$2"
}

parse_avreg_conf() {
   local par_conf_name par_name par_value

   for par_conf_name in $@; do
      par_name=$(echo $par_conf_name | tr '-' '_')
      par_value=$(eval "echo \${$par_name}")
      if [ -z "${par_value}" ]; then
         par_value=$(global_value_of "$par_conf_name" "$OPT_AVREG_CONF")
         eval "$par_name='$par_value'"
      fi
   done
}

# freespace_greater_than_mb dir mb
# return 0 if it is greater than or equal to mb
freespace_greater_than_mb() {
   local dir sz free_sz
   dir="$1"
   sz="$2"
   [ -z "$dir" -o -z "$sz" ] && return 2
   if [ ! -e "$dir" ]; then
      dir="${dir%/*}"
      [ -z "$dir" ] && return 2
   fi
   if [ -d "$dir" -o -L "$dir" ]; then
      free_sz="$(LC_ALL=C BLOCKSIZE= df -m --portability ${dir}/. | tail -n 1 | awk '{ print $4 }')"
      test ${free_sz} -gt ${sz}
   else
      return 2
   fi
}

my_mkdir() {
   local dir own_user own_group mode
   dir="$1"
   own_user="$2"
   own_group="$3"
   mode="$4"

   if [ ! -d "$dir" -a ! -L "$dir" ]; then
      mkdir "$dir"
      chown "$own_user:$own_group" "$dir"
      chmod "$mode" "$dir"
   fi
}

is_localhost() {
   local host=$1 addr

   if [ -z "$host" -o "$host" = '127.0.0.1' -o "$host" = 'localhost' -o "$host" = '::1' ]; then
      return 0
   fi

   if hostname -I | grep -qw "$host"; then
      return 0
   fi

   for addr in $(getent hosts $host | awk '{ print $1 }'); do
      if [ -o "$addr" = '127.0.0.1' -o "$addr" = '::1' ]; then
         return 0
      fi
   done

   return 1
}

safe_rm_fR() {
   local o= r= d=

   [ -z "$1" ] && return 1

   for o in $@; do
      r=$(realpath "$o")
      d=$(dirname "$r")
      if echo '/ /boot /bin /dev /etc /home /lib /media /mnt /opt /proc /root /sbin /srv /sys /usr /var' | grep -qw "$d"; then
         return 1
      fi
   done

   rm -fR $@
}

get_var_val() {
   local var_name=$1

   echo $(eval echo \$${var_name})
}

log() {
   if [ "$OPT_BEQUIET" != 'yes' ]; then
      printf "%s\t" "$(date +'%F %T')"
      echo $*
   fi
}

log_error() {
   if [ -n "$1" ]; then
      printf "%s\tError: %s\n" "$(date +'%F %T')" "$*" >&2
      echo >&2
   fi
}

log_warn() {
   if [ -n "$1" ]; then
      printf "%s\tWarning: %s\n" "$(date +'%F %T')" "$*" >&2
      echo >&2
   fi
}

is_dir_empty() {
   local dir="$1"

   [ -d "$dir" ] || return 2

   if [ -z $(find "$dir" -maxdepth 0 -empty 2>/dev/null) ]; then
      return 1
   fi

   return 0
}
alias is_empty_dir='is_dir_empty'

check_deb_status() {
   dpkg-query -s "$1" 2>/dev/null | grep -qw "$2"
}

get_random_string() {
   local chars_limit=${1:-10} chars_set=${2:-A\-Za\-z0\-9}
   tr -dc "$chars_set" </dev/urandom | head -c $chars_limit
}

is_execs_exist() {
   for bin in $@; do
      if [ -x "$(which $bin 2>/dev/null)" ]; then
         :
      else
         return $?
      fi
   done

   return 0
}
