--                ~ utf-8 ~

SET NAMES 'utf8' COLLATE 'utf8_general_ci';

--
-- Структура таблицы `CAMERAS`
--

CREATE TABLE `CAMERAS` (
  `BIND_MAC` varchar(17)  CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'BIND MAC ADDR: xx:xx:xx-xx:xx:xx or local',
  `CAM_NR` smallint NOT NULL,
  `PARNAME` varchar(30) CHARACTER SET ascii COLLATE ascii_bin NOT NULL,
  `PARVAL` varchar(1000) NULL DEFAULT NULL,
  `CHANGE_HOST` varchar(60) NOT NULL,
  `CHANGE_USER` varchar(16) NOT NULL,
  `CHANGE_TIME` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`BIND_MAC`,`CAM_NR`,`PARNAME`)
);

--
-- Структура таблицы `EVENTS`
--
CREATE TABLE `EVENTS` (
  `DT1` datetime NOT NULL,
  `DT2` datetime NOT NULL,
  `CAM_NR` smallint NOT NULL,
  `EVT_ID` tinyint NOT NULL,
  `SESS_NR` integer NOT NULL,
  `FILESZ_KB` integer NOT NULL COMMENT 'KiloBytes',
  `FRAMES` integer NOT NULL,
  `ALT1` integer NOT NULL,
  `ALT2` integer NOT NULL,
  `EVT_CONT` varchar(150) NOT NULL
) CHARSET=ascii COLLATE=ascii_bin;
--
-- Индексы таблицы `EVENTS`
--
ALTER TABLE `EVENTS`
  ADD KEY `DT1_CAM_EVT` (`DT1`,`CAM_NR`,`EVT_ID`),
  ADD KEY `DT2_CAM_EVT` (`DT2`,`CAM_NR`,`EVT_ID`);

--
-- Структура таблицы `TREE_EVENTS`
--
CREATE TABLE `TREE_EVENTS` (
  `BYHOUR` char(13) CHARACTER SET ascii COLLATE ascii_bin NOT NULL,
  `CAM_NR` smallint NOT NULL,
  `DT1_MAX` datetime NOT NULL,
  `DT1_MIN` datetime NOT NULL,
  `IMAGE_COUNT` integer NOT NULL DEFAULT 0,
  `IMAGE_SIZE` integer NOT NULL DEFAULT 0,
  `VIDEO_COUNT` integer NOT NULL DEFAULT 0,
  `VIDEO_SIZE` integer NOT NULL DEFAULT 0,
  `AUDIO_COUNT` integer NOT NULL DEFAULT 0,
  `AUDIO_SIZE` integer NOT NULL DEFAULT 0
) CHARSET=ascii COLLATE=ascii_bin;
--
-- Индексы таблицы `TREE_EVENTS`
--
ALTER TABLE `TREE_EVENTS`
 ADD PRIMARY KEY (`BYHOUR`,`CAM_NR`),
 ADD KEY `DT1_MAX_IDX` (`DT1_MAX`),
 ADD KEY `DT1_MIN_IDX` (`DT1_MIN`);

--
-- Структура таблицы `USERS`
--

CREATE TABLE `USERS` (
  `ALLOW_FROM` varchar(511) CHARACTER SET ascii COLLATE ascii_bin NOT NULL,
  `USER_LOGIN` varchar(16) CHARACTER SET ascii COLLATE ascii_bin NOT NULL,
  `PASSWD` varchar(80) CHARACTER SET ascii COLLATE ascii_bin NOT NULL,
  `STATUS` integer NOT NULL COMMENT 'AVReg user group',
  `GUEST` integer NOT NULL DEFAULT '0' COMMENT 'Allows GUEST mode',
  `PDA` integer NOT NULL DEFAULT '1' COMMENT 'Allows pda/* access',
  `ALLOW_CAMS` varchar(511) CHARACTER SET ascii COLLATE ascii_bin NULL DEFAULT NULL COMMENT 'Cameras ACL',
  `ALLOW_LAYOUTS` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NULL DEFAULT NULL COMMENT 'Web layouts ACL',
  `MAX_FORCED_REC_MINUTES` integer NULL DEFAULT NULL COMMENT 'in minutes',
  `MAX_MEDIA_SESSIONS_NB` integer NULL DEFAULT NULL,
  `MAX_VIDEO_FPS` varchar(5) CHARACTER SET ascii COLLATE ascii_bin DEFAULT NULL,
  `MAX_VIDEO_NONMOTION_FPS` varchar(5) CHARACTER SET ascii COLLATE ascii_bin DEFAULT NULL,
  `MAX_MEDIA_SESSION_RATE_KB` integer NULL DEFAULT NULL,
  `MAX_MEDIA_SESSION_MINUTES` integer NULL DEFAULT NULL COMMENT 'in minutes',
  `MAX_MEDIA_SESSION_VOLUME_MB` integer NULL DEFAULT NULL COMMENT 'in MBytes',
  `LONGNAME` varchar(100) NOT NULL,
  `CHANGE_HOST` varchar(60) NOT NULL,
  `CHANGE_USER` varchar(16) NOT NULL,
  `CHANGE_TIME` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`ALLOW_FROM`,`USER_LOGIN`)
) CHARSET=utf8 COLLATE=utf8_general_ci;

--
-- Структура таблицы `MONITORS`
--

CREATE TABLE `LOCAL_LAYOUTS` (
  `BIND_MAC` varchar(17) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `DISPLAY` char(1) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT 'L' COMMENT '(L)eft or (R)ight on dual-head system',
  `MON_NR` smallint NOT NULL,
  `MON_TYPE` varchar(16) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `MON_NAME` varchar(16) NOT NULL,
  `IS_DEFAULT` tinyint NOT NULL DEFAULT '0',
  `WIN1` smallint NULL DEFAULT NULL,
  `WIN2` smallint NULL DEFAULT NULL,
  `WIN3` smallint NULL DEFAULT NULL,
  `WIN4` smallint NULL DEFAULT NULL,
  `WIN5` smallint NULL DEFAULT NULL,
  `WIN6` smallint NULL DEFAULT NULL,
  `WIN7` smallint NULL DEFAULT NULL,
  `WIN8` smallint NULL DEFAULT NULL,
  `WIN9` smallint NULL DEFAULT NULL,
  `WIN10` smallint NULL DEFAULT NULL,
  `WIN11` smallint NULL DEFAULT NULL,
  `WIN12` smallint NULL DEFAULT NULL,
  `WIN13` smallint NULL DEFAULT NULL,
  `WIN14` smallint NULL DEFAULT NULL,
  `WIN15` smallint NULL DEFAULT NULL,
  `WIN16` smallint NULL DEFAULT NULL,
  `WIN17` smallint NULL DEFAULT NULL,
  `WIN18` smallint NULL DEFAULT NULL,
  `WIN19` smallint NULL DEFAULT NULL,
  `WIN20` smallint NULL DEFAULT NULL,
  `WIN21` smallint NULL DEFAULT NULL,
  `WIN22` smallint NULL DEFAULT NULL,
  `WIN23` smallint NULL DEFAULT NULL,
  `WIN24` smallint NULL DEFAULT NULL,
  `WIN25` smallint NULL DEFAULT NULL,
  `WIN26` smallint NULL DEFAULT NULL,
  `WIN27` smallint NULL DEFAULT NULL,
  `WIN28` smallint NULL DEFAULT NULL,
  `WIN29` smallint NULL DEFAULT NULL,
  `WIN30` smallint NULL DEFAULT NULL,
  `WIN31` smallint NULL DEFAULT NULL,
  `WIN32` smallint NULL DEFAULT NULL,
  `WIN33` smallint NULL DEFAULT NULL,
  `WIN34` smallint NULL DEFAULT NULL,
  `WIN35` smallint NULL DEFAULT NULL,
  `WIN36` smallint NULL DEFAULT NULL,
  `WIN37` smallint NULL DEFAULT NULL,
  `WIN38` smallint NULL DEFAULT NULL,
  `WIN39` smallint NULL DEFAULT NULL,
  `WIN40` smallint NULL DEFAULT NULL,
  `WIN41` smallint NULL DEFAULT NULL,
  `WIN42` smallint NULL DEFAULT NULL,
  `WIN43` smallint NULL DEFAULT NULL,
  `WIN44` smallint NULL DEFAULT NULL,
  `WIN45` smallint NULL DEFAULT NULL,
  `WIN46` smallint NULL DEFAULT NULL,
  `WIN47` smallint NULL DEFAULT NULL,
  `WIN48` smallint NULL DEFAULT NULL,
  `WIN49` smallint NULL DEFAULT NULL,
  `WIN50` smallint NULL DEFAULT NULL,
  `WIN51` smallint NULL DEFAULT NULL,
  `WIN52` smallint NULL DEFAULT NULL,
  `WIN53` smallint NULL DEFAULT NULL,
  `WIN54` smallint NULL DEFAULT NULL,
  `WIN55` smallint NULL DEFAULT NULL,
  `WIN56` smallint NULL DEFAULT NULL,
  `WIN57` smallint NULL DEFAULT NULL,
  `WIN58` smallint NULL DEFAULT NULL,
  `WIN59` smallint NULL DEFAULT NULL,
  `WIN60` smallint NULL DEFAULT NULL,
  `CHANGE_HOST` varchar(60) NOT NULL,
  `CHANGE_USER` varchar(16) NOT NULL,
  `CHANGE_TIME` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`BIND_MAC`,`DISPLAY`,`MON_NR`)
);

CREATE TABLE IF NOT EXISTS `WEB_LAYOUTS` (
  `BIND_MAC` varchar(17) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `MON_NR` smallint NOT NULL,
  `MON_TYPE` varchar(16) CHARACTER SET ascii NOT NULL,
  `SHORT_NAME` varchar(16) NOT NULL,
  `IS_DEFAULT` tinyint NOT NULL DEFAULT '0',
  `PRINT_CAM_NAME` int DEFAULT NULL COMMENT 'true - print the cameras names; false - don not show',
  `PROPORTION` varchar(5) DEFAULT NULL COMMENT 'calc - to show with proportion; fs - to stretch to full screen',
  `RECONNECT_TOUT` int DEFAULT NULL COMMENT 'reconnect timeout in seconds',
  `STOP_HIDDEN_CAMS` tinyint NOT NULL DEFAULT 1,
  `WINS` varchar(3000) NOT NULL,
  `CHANGE_HOST` varchar(60) NOT NULL,
  `CHANGE_USER` varchar(16) NOT NULL,
  `CHANGE_TIME` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`BIND_MAC`,`MON_NR`)
);
