SET NAMES 'utf8';

-- DROP TABLE IF EXISTS CAMERAS;
CREATE TABLE CAMERAS (
  BIND_MAC character varying(17)  NOT NULL, -- BIND MAC ADDR: xx:xx:xx-xx:xx:xx or local
  CAM_NR smallint  NOT NULL,
  PARNAME character varying(30) NOT NULL, -- rename from PARAM
  PARVAL character varying(1000) DEFAULT NULL, -- rename from VALUE, SQL92 reserved
  CHANGE_HOST character varying(60) NOT NULL,
  CHANGE_USER character varying(16) NOT NULL,
  CHANGE_TIME timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (BIND_MAC,CAM_NR,PARNAME)
);


-- DROP TABLE IF EXISTS EVENTS;
CREATE TABLE EVENTS (
  DT1 timestamp without time zone NOT NULL,
  DT2 timestamp without time zone NOT NULL,
  CAM_NR smallint  NOT NULL,
  EVT_ID smallint  NOT NULL,
  SESS_NR integer  NOT NULL, -- motion/record session number, rename from SER_NR
  FILESZ_KB integer  NOT NULL, -- KiloBytes
  FRAMES integer  NOT NULL,
  ALT1 integer  NOT NULL, -- rename from U16_1
  ALT2 integer  NOT NULL, -- rename from U16_1
  EVT_CONT character varying (150)  NOT NULL
);

-- DROP INDEX  IF EXISTS EVT_IDX;
CREATE INDEX DT1_CAM_EVT ON EVENTS (DT1, CAM_NR, EVT_ID);
CREATE INDEX DT2_CAM_EVT ON EVENTS (DT2, CAM_NR, EVT_ID);

-- DROP TABLE IF EXISTS TREE_EVENTS;
CREATE TABLE TREE_EVENTS (
  BYHOUR char(13) NOT NULL, -- rename from DATE, SQL92 reserved
  CAM_NR smallint NOT NULL,
  DT1_MAX timestamp without time zone NOT NULL,
  DT1_MIN timestamp without time zone NOT NULL,
  IMAGE_COUNT integer NOT NULL DEFAULT '0',
  IMAGE_SIZE integer NOT NULL DEFAULT '0',
  VIDEO_COUNT integer NOT NULL DEFAULT '0',
  VIDEO_SIZE integer NOT NULL DEFAULT '0',
  AUDIO_COUNT integer NOT NULL DEFAULT '0',
  AUDIO_SIZE integer NOT NULL DEFAULT '0',
  PRIMARY KEY (BYHOUR,CAM_NR)
);
CREATE INDEX dt1_max_idx on TREE_EVENTS (DT1_MAX);
CREATE INDEX dt1_min_idx on TREE_EVENTS (DT1_MIN);

-- DROP TABLE IF EXISTS LOCAL_LAYOUTS;
CREATE TABLE LOCAL_LAYOUTS (
  BIND_MAC character varying(17)  NOT NULL,
  DISPLAY char(1)  NOT NULL DEFAULT 'L', -- (L)eft or (R)ight on dual-head system
  MON_NR smallint  NOT NULL,
  MON_TYPE character varying(16)  NOT NULL,
  MON_NAME character varying(16) NOT NULL,
  IS_DEFAULT smallint  NOT NULL DEFAULT '0',
  WIN1 smallint  DEFAULT NULL,
  WIN2 smallint  DEFAULT NULL,
  WIN3 smallint  DEFAULT NULL,
  WIN4 smallint  DEFAULT NULL,
  WIN5 smallint  DEFAULT NULL,
  WIN6 smallint  DEFAULT NULL,
  WIN7 smallint  DEFAULT NULL,
  WIN8 smallint  DEFAULT NULL,
  WIN9 smallint  DEFAULT NULL,
  WIN10 smallint  DEFAULT NULL,
  WIN11 smallint  DEFAULT NULL,
  WIN12 smallint  DEFAULT NULL,
  WIN13 smallint  DEFAULT NULL,
  WIN14 smallint  DEFAULT NULL,
  WIN15 smallint  DEFAULT NULL,
  WIN16 smallint  DEFAULT NULL,
  WIN17 smallint  DEFAULT NULL,
  WIN18 smallint  DEFAULT NULL,
  WIN19 smallint  DEFAULT NULL,
  WIN20 smallint  DEFAULT NULL,
  WIN21 smallint  DEFAULT NULL,
  WIN22 smallint  DEFAULT NULL,
  WIN23 smallint  DEFAULT NULL,
  WIN24 smallint  DEFAULT NULL,
  WIN25 smallint  DEFAULT NULL,
  WIN26 smallint  DEFAULT NULL,
  WIN27 smallint  DEFAULT NULL,
  WIN28 smallint  DEFAULT NULL,
  WIN29 smallint  DEFAULT NULL,
  WIN30 smallint  DEFAULT NULL,
  WIN31 smallint  DEFAULT NULL,
  WIN32 smallint  DEFAULT NULL,
  WIN33 smallint  DEFAULT NULL,
  WIN34 smallint  DEFAULT NULL,
  WIN35 smallint  DEFAULT NULL,
  WIN36 smallint  DEFAULT NULL,
  WIN37 smallint  DEFAULT NULL,
  WIN38 smallint  DEFAULT NULL,
  WIN39 smallint  DEFAULT NULL,
  WIN40 smallint  DEFAULT NULL,
  WIN41 smallint  DEFAULT NULL,
  WIN42 smallint  DEFAULT NULL,
  WIN43 smallint  DEFAULT NULL,
  WIN44 smallint  DEFAULT NULL,
  WIN45 smallint  DEFAULT NULL,
  WIN46 smallint  DEFAULT NULL,
  WIN47 smallint  DEFAULT NULL,
  WIN48 smallint  DEFAULT NULL,
  WIN49 smallint  DEFAULT NULL,
  WIN50 smallint  DEFAULT NULL,
  WIN51 smallint  DEFAULT NULL,
  WIN52 smallint  DEFAULT NULL,
  WIN53 smallint  DEFAULT NULL,
  WIN54 smallint  DEFAULT NULL,
  WIN55 smallint  DEFAULT NULL,
  WIN56 smallint  DEFAULT NULL,
  WIN57 smallint  DEFAULT NULL,
  WIN58 smallint  DEFAULT NULL,
  WIN59 smallint  DEFAULT NULL,
  WIN60 smallint  DEFAULT NULL,
  CHANGE_HOST character varying(60) NOT NULL,
  CHANGE_USER character varying(16) NOT NULL,
  CHANGE_TIME timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (BIND_MAC,DISPLAY,MON_NR)
);

-- DROP TABLE IF EXISTS USERS;
CREATE TABLE USERS (
  ALLOW_FROM character varying(511) NOT NULL, -- rename from HOST, SQL:1999 reserved
  USER_LOGIN character varying(16) NOT NULL, -- rename from USER, SQL92 reserved
  PASSWD character varying(80) DEFAULT NULL,
  STATUS smallint  NOT NULL,
  GUEST smallint  DEFAULT 0,
  PDA smallint  DEFAULT 1,
  ALLOW_CAMS character varying(511) DEFAULT NULL, -- Cameras ACL
  ALLOW_LAYOUTS character varying(255) DEFAULT NULL, -- Web Layouts ACL
  MAX_FORCED_REC_MINUTES integer  DEFAULT NULL, -- in minutes
  MAX_MEDIA_SESSIONS_NB integer  DEFAULT NULL,
  MAX_VIDEO_FPS character varying(5)   DEFAULT NULL,
  MAX_VIDEO_NONMOTION_FPS character varying(5)   DEFAULT NULL,
  MAX_MEDIA_SESSION_RATE_KB integer  DEFAULT NULL,
  MAX_MEDIA_SESSION_MINUTES integer  DEFAULT NULL , -- in minutes
  MAX_MEDIA_SESSION_VOLUME_MB integer  DEFAULT NULL , -- in MBytes
  LONGNAME character varying(100) NOT NULL,
  CHANGE_HOST character varying(60) NOT NULL,
  CHANGE_USER character varying(16) NOT NULL,
  CHANGE_TIME timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (ALLOW_FROM,USER_LOGIN)
);
CREATE EXTENSION IF NOT EXISTS pgcrypto;

CREATE TABLE WEB_LAYOUTS (
  BIND_MAC character varying(17)  NOT NULL,
  MON_NR smallint NOT NULL,
  MON_TYPE character varying(16) NOT NULL,
  SHORT_NAME character varying(16) NOT NULL,
  IS_DEFAULT smallint NOT NULL DEFAULT 0,
  PRINT_CAM_NAME smallint DEFAULT NULL, -- true - print the cameras names; false - don not show
  PROPORTION character varying(5) DEFAULT NULL, -- calc - to show with proportion; fs - to stretch to full screen
  RECONNECT_TOUT int DEFAULT NULL, -- reconnect timeout in seconds
  STOP_HIDDEN_CAMS smallint NOT NULL DEFAULT 1,
  WINS character varying(3000) NOT NULL,
  CHANGE_HOST character varying(60) NOT NULL,
  CHANGE_USER character varying(16) NOT NULL,
  CHANGE_TIME timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (BIND_MAC,MON_NR)
);
